==> ejc-law-api-3.0.0-20221101.090835-17-sources.jar: com/ejianc/business/law/vo/AgentVO.java <==
package com.ejianc.business.law.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 代理单位登记表
 * 
 * @author generator
 * 
 */
public class AgentVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String agentOrgCode; // 代理联系方式
    private String agentOrgName; // 代理单位名称
    private String address; // 代理单位地址
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getAgentOrgCode() {
        return agentOrgCode;
    }

    public void setAgentOrgCode(String agentOrgCode) {
        this.agentOrgCode = agentOrgCode;
    }
    public String getAgentOrgName() {
        return agentOrgName;
    }

    public void setAgentOrgName(String agentOrgName) {
        this.agentOrgName = agentOrgName;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    
}

==> ejc-law-api-3.0.0-20250213.101320-125-sources.jar: com/ejianc/business/law/vo/AgentVO.java <==
package com.ejianc.business.law.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 代理单位登记表
 * 
 * @author generator
 * 
 */
public class AgentVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String agentOrgCode; // 代理单位编号
    private String agentOrgName; // 代理单位名称
    private String address; // 代理单位地址
    private String agentPhone;//联系方式
    private List<AgentZiVO> agentZiList = new ArrayList<>(); // 代理单位登记子表


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getAgentOrgCode() {
        return agentOrgCode;
    }

    public void setAgentOrgCode(String agentOrgCode) {
        this.agentOrgCode = agentOrgCode;
    }
    public String getAgentOrgName() {
        return agentOrgName;
    }

    public void setAgentOrgName(String agentOrgName) {
        this.agentOrgName = agentOrgName;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getAgentPhone() {
        return agentPhone;
    }

    public void setAgentPhone(String agentPhone) {
        this.agentPhone = agentPhone;
    }

    public List<AgentZiVO> getAgentZiList() {
        return agentZiList;
    }

    public void setAgentZiList(List<AgentZiVO> agentZiList) {
        this.agentZiList = agentZiList;
    }
}
